/**
 * @mainpage ASCII
 * @brief  ASCII codes for uses with AVR librairies
 * @author Patrice Nadeau  <patricen@telwarwick.net>
 * @n www : http://nadeaup.homeip.net
 * @section License
Copyright (c) 2009, 2010, 2011 Patrice Nadeau
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    - Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    - Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    - Neither the name of Patrice Nadeau nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL Patrice Nadeau BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 * @section Specifications
 *
 * @subsection Language
 * - C (c99)
 * @subsection Compiler
 * - avr-gcc
 * @subsection Target
 * - ALL
 *
 * @section information More informations
 * */

/**
 * @file ascii.h
 * @brief ASCII code
 * @author Patrice Nadeau <patricen@telwarwick.net>
 * @todo Make all number and not a mix
 */

/**
 * @name Useful characters
 * @{ */
/** @brief To terminate a string ('\0') */
#define ascii_NULL 0
/** @brief End of Transmission */
#define ascii_EOT 4
/** @brief Backspace */
#define ascii_BS 8
/** @brief Enter */
#define ascii_ENTER 13
/** @brief Escape */
#define ascii_ESC 27
/** @brief Space */
#define ascii_SPACE 32
/** @brief Delete */
#define ascii_DEL 127
/** @brief Carriage Return */
#define ascii_CR '\r'
/** @brief Line Feed */
#define ascii_LF '\n'
/**
 * @brief Add this number to convert to a ASCII number
 * @par Example
 *
 * @code
 * usart_SendCharacter(2 + ascii_NUMERIC_OFFSET)
 * @endcode */
#define ascii_NUMERIC_OFFSET 48

/** @} */

/* change log
 * 2011-03-06 Patrice Nadeau
 * First draft
 * 2011-03-27 Patrice Nadeau
 * Add a few more ASCII definition
 */
